@@ -36,10 +36,7 @@
              $addgraphics_virtualDomains, $left_image_url, $image_height, 
              $image_width, $div_style;
 
-      if (compatibility_check_sm_version(1, 3))
-         include_once(SM_PATH . 'plugins/addgraphics/config.php');
-      else
-         include_once('../plugins/addgraphics/config.php');
+      include_once(SM_PATH . 'plugins/addgraphics/config.php');
 
 
       if ($differentImagePerDomain) {
@@ -59,26 +56,89 @@
 
          // get the correct image for this domain
          //
+         $check_image_width = FALSE;
+         $new_left_image = '';
+         $new_left_image_alt = '';
+         $new_left_image_url = '';
+         $new_image_width = '';
+         $new_image_height = '';
+         $new_div_style = '';
          foreach (array_keys($addgraphics_virtualDomains) as $virtualDomain) {
 
             if (stristr($hostname, $virtualDomain)) {
 
-               $left_image = $addgraphics_virtualDomains[$virtualDomain]['left_image'];
-               $left_image_alt = $addgraphics_virtualDomains[$virtualDomain]['left_image_alt'];
-               $left_image_url = $addgraphics_virtualDomains[$virtualDomain]['left_image_url'];
+               $new_left_image = $addgraphics_virtualDomains[$virtualDomain]['left_image'];
+               $new_left_image_alt = $addgraphics_virtualDomains[$virtualDomain]['left_image_alt'];
+               $new_left_image_url = $addgraphics_virtualDomains[$virtualDomain]['left_image_url'];
 
                if (isset($addgraphics_virtualDomains[$virtualDomain]['image_width']))
-                  $image_width = $addgraphics_virtualDomains[$virtualDomain]['image_width'];
+                  $new_image_width = $addgraphics_virtualDomains[$virtualDomain]['image_width'];
                else
-                  $image_width = $left_size - 20;
+                  $check_image_width = TRUE;
 
                if (isset($addgraphics_virtualDomains[$virtualDomain]['image_height']))
-                  $image_height = $addgraphics_virtualDomains[$virtualDomain]['image_height'];
+                  $new_image_height = $addgraphics_virtualDomains[$virtualDomain]['image_height'];
 
                if (isset($addgraphics_virtualDomains[$virtualDomain]['div_style']))
-                  $div_style = $addgraphics_virtualDomains[$virtualDomain]['div_style'];
+                  $new_div_style = $addgraphics_virtualDomains[$virtualDomain]['div_style'];
             }
          }
+
+
+         // if not found, look for global settings from vlogin
+         if (empty($new_left_image))
+         {
+            global $addgraphics_left_image;
+            if (!empty($addgraphics_left_image))
+            {
+               $new_left_image = $addgraphics_left_image;
+
+               if (empty($new_image_width))
+               {
+                  global $addgraphics_image_width;
+                  if (!empty($addgraphics_image_width))
+                     $new_image_width = $addgraphics_image_width;
+                  else
+                     $check_image_width = TRUE;
+               }
+            }
+         }
+         if (empty($new_left_image_alt))
+         {
+            global $addgraphics_left_image_alt;
+            if (!empty($addgraphics_left_image_alt))
+               $new_left_image_alt = $addgraphics_left_image_alt;
+         }
+         if (empty($new_left_image_url))
+         {
+            global $addgraphics_left_image_url;
+            if (!empty($addgraphics_left_image_url))
+               $new_left_image_url = $addgraphics_left_image_url;
+         }
+         if (empty($new_image_height))
+         {
+            global $addgraphics_image_height;
+            if (!empty($addgraphics_image_height))
+               $new_image_height = $addgraphics_image_height;
+         }
+         if (empty($new_div_style))
+         {
+            global $addgraphics_div_style;
+            if (!empty($addgraphics_div_style))
+               $new_div_style = $addgraphics_div_style;
+         }
+
+
+         if (!empty($new_left_image)) $left_image = $new_left_image;
+         if (!empty($new_image_width)) $image_width = $new_image_width;
+         if (!empty($new_left_image_alt)) $left_image_alt = $new_left_image_alt;
+         if (!empty($new_left_image_url)) $left_image_url = $new_left_image_url;
+         if (!empty($new_image_height)) $image_height = $new_image_height;
+         if (!empty($new_div_style)) $div_style = $new_div_style;
+
+         if ($check_image_width && empty($image_width))
+            $image_width = $left_size - 20;
+
       }
 
 
