@@ -20,27 +20,42 @@
     *
     */
 
-   function squirrelmail_plugin_init_addgraphics() {
-      global $squirrelmail_plugin_hooks;
-      $squirrelmail_plugin_hooks["left_main_before"]["addgraphics"] = "addgraph_left";
-   }
+
+if (!defined('SM_PATH'))
+   define('SM_PATH', '../');
 
 
-   function addgraph_left() {
 
-      if (defined('SM_PATH'))
-         include_once(SM_PATH . 'plugins/addgraphics/functions.php');
-      else
-         include_once('../plugins/addgraphics/functions.php');
-
-      addgraph_left_do();
-
-   }
+/**
+  * Register this plugin with SquirrelMail
+  *
+  */
+function squirrelmail_plugin_init_addgraphics() 
+{
+   global $squirrelmail_plugin_hooks;
+   $squirrelmail_plugin_hooks["left_main_before"]["addgraphics"] = "addgraph_left";
+}
 
 
-   function addgraphics_version()
-   {
-      return '2.1';
-   }
+/**
+  * Returns version info about this plugin
+  *
+  */
+function addgraph_left() 
+{
+   include_once(SM_PATH . 'plugins/addgraphics/functions.php');
+   addgraph_left_do();
+}
+
+
+/**
+  * Returns version info about this plugin
+  *
+  */
+function addgraphics_version()
+{
+   return '2.3';
+}
+
 
 ?>
